==> styletron-react-2.0.0.tgz: package/lib/test/browser.js <==
var test = require('tape');
var React = require('react');
var ReactTestUtils = require('react-addons-test-utils');
var Styletron = require('styletron-server');

var styled = require('../styled');
var Provider = require('../provider');

test('provider provides instance', function (t) {
  var mockInstance = {};
  var MockComponent = function (props, context) {
    t.equal(context.styletron, mockInstance, 'styletron instance override provided');
    return React.createElement('div');
  };
  MockComponent.contextTypes = {styletron: React.PropTypes.object};
  ReactTestUtils.renderIntoDocument(React.createElement(Provider, {
    styletron: mockInstance
  }, React.createElement(MockComponent)));
  t.end();
});

test('props passed to styled function', function (t) {
  t.plan(1);
  var props = {
    prop1: 'foo'
  };
  var Widget = styled('div', function (props) {
    t.deepEqual(props, props, 'props accessible in style fn');
    return {};
  });
  var styletron = new Styletron();
  ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Widget, props))
  );
});

test('styled applies styles', function (t) {
  var Widget = styled('div', function () {
    return {color: 'red'};
  });
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Widget))
  );
  var div = ReactTestUtils.findRenderedDOMComponentWithTag(output, 'div');
  t.equal(div.className, ' c0', 'styletron classes');
  t.equal(styletron.getCss(), '.c0{color:red}');
  t.end();
});

test('styled applies static styles', function (t) {
  var Widget = styled('div', {color: 'red'});
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Widget))
  );
  var div = ReactTestUtils.findRenderedDOMComponentWithTag(output, 'div');
  t.equal(div.className, ' c0', 'matches expected styletron classes');
  t.equal(styletron.getCss(), '.c0{color:red}');
  t.end();
});

test('styled passes through valid props', function (t) {
  var Widget = styled('div', {color: 'red'});
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Widget, {
        'data-bar': 'bar'
      }))
  );
  var div = ReactTestUtils.findRenderedDOMComponentWithTag(output, 'div');
  t.equal(div.getAttribute('data-bar'), 'bar', 'valid attribute prop passed through');
  t.end();
});

test('styled composition', function (t) {
  var Widget = styled('div', {color: 'red', 'display': 'inline'});
  var SuperWidget = styled(Widget, {display: 'block', background: 'black'});
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(SuperWidget))
  );
  var div = ReactTestUtils.findRenderedDOMComponentWithTag(output, 'div');
  t.equal(div.className, ' c0 c1 c2', 'matches expected styletron classes');
  t.equal(styletron.getCss(), '.c0{color:red}.c1{display:block}.c2{background:black}');
  t.end();
});

==> styletron-react-2.0.4.tgz: package/lib/test/browser.js <==
var test = require('tape');
var React = require('react');
var ReactTestUtils = require('react-addons-test-utils');
var Styletron = require('styletron-server');

var styled = require('../styled');
var Provider = require('../provider');

test('provider provides instance', function (t) {
  var mockInstance = {};
  var MockComponent = function (props, context) {
    t.equal(context.styletron, mockInstance, 'styletron instance override provided');
    return React.createElement('div');
  };
  MockComponent.contextTypes = {styletron: React.PropTypes.object};
  ReactTestUtils.renderIntoDocument(React.createElement(Provider, {
    styletron: mockInstance
  }, React.createElement(MockComponent)));
  t.end();
});

test('props passed to styled function', function (t) {
  t.plan(1);
  var props = {
    prop1: 'foo'
  };
  var Widget = styled('div', function (props) {
    t.deepEqual(props, props, 'props accessible in style fn');
    return {};
  });
  var styletron = new Styletron();
  ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Widget, props))
  );
});

test('styled applies styles', function (t) {
  var Widget = styled('div', function () {
    return {color: 'red'};
  });
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Widget))
  );
  var div = ReactTestUtils.findRenderedDOMComponentWithTag(output, 'div');
  t.equal(div.className, ' s0', 'styletron classes');
  t.equal(styletron.getCss(), '.s0{color:red}');
  t.end();
});

test('styled applies static styles', function (t) {
  var Widget = styled('div', {color: 'red'});
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Widget))
  );
  var div = ReactTestUtils.findRenderedDOMComponentWithTag(output, 'div');
  t.equal(div.className, ' s0', 'matches expected styletron classes');
  t.equal(styletron.getCss(), '.s0{color:red}');
  t.end();
});

test('styled passes through valid props', function (t) {
  var Widget = styled('div', {color: 'red'});
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(Widget, {
        'data-bar': 'bar'
      }))
  );
  var div = ReactTestUtils.findRenderedDOMComponentWithTag(output, 'div');
  t.equal(div.getAttribute('data-bar'), 'bar', 'valid attribute prop passed through');
  t.end();
});

test('styled composition', function (t) {
  var Widget = styled('div', {color: 'red', 'display': 'inline'});
  var SuperWidget = styled(Widget, {display: 'block', background: 'black'});
  var styletron = new Styletron();
  var output = ReactTestUtils.renderIntoDocument(
    React.createElement(Provider, {styletron: styletron},
      React.createElement(SuperWidget))
  );
  var div = ReactTestUtils.findRenderedDOMComponentWithTag(output, 'div');
  t.equal(div.className, ' s0 s1 s2', 'matches expected styletron classes');
  t.equal(styletron.getCss(), '.s0{color:red}.s1{display:block}.s2{background:black}');
  t.end();
});
